# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_cross_stage_violation_dtov2 import ApiCrossStageViolationDTOV2

class TestApiCrossStageViolationDTOV2(unittest.TestCase):
    """ApiCrossStageViolationDTOV2 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiCrossStageViolationDTOV2:
        """Test ApiCrossStageViolationDTOV2
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiCrossStageViolationDTOV2`
        """
        model = ApiCrossStageViolationDTOV2()
        if include_optional:
            return ApiCrossStageViolationDTOV2(
                application_name = '',
                application_public_id = '',
                component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                    coordinates = {
                        'key' : ''
                        }, 
                    format = '', ),
                constraint_violations = [
                    sonatype_iq_api_client.models.api_constraint_violation_dto.ApiConstraintViolationDTO(
                        constraint_id = '', 
                        constraint_name = '', 
                        reasons = [
                            sonatype_iq_api_client.models.api_constraint_violation_reason_dto.ApiConstraintViolationReasonDTO(
                                reason = '', 
                                reference = sonatype_iq_api_client.models.trigger_reference.TriggerReference(
                                    type = 'SECURITY_VULNERABILITY_REFID', 
                                    value = '', ), )
                            ], )
                    ],
                display_name = sonatype_iq_api_client.models.component_display_name.ComponentDisplayName(
                    name = '', 
                    parts = [
                        sonatype_iq_api_client.models.component_display_name_part.ComponentDisplayNamePart(
                            field = '', 
                            value = '', )
                        ], ),
                filename = '',
                fix_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                hash = '',
                legacy_violation_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                open_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                organization_name = '',
                policy_id = '',
                policy_name = '',
                policy_owner = sonatype_iq_api_client.models.policy_owner.PolicyOwner(
                    owner_id = '', 
                    owner_name = '', 
                    owner_public_id = '', 
                    owner_type = '', ),
                policy_threat_category = '',
                policy_violation_id = '',
                reachability_status = 'REACHABLE',
                stage_data = {
                    'key' : sonatype_iq_api_client.models.stage_data.StageData(
                        action_type_id = '', 
                        most_recent_evaluation_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        most_recent_scan_id = '', )
                    },
                threat_level = 56,
                waive_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return ApiCrossStageViolationDTOV2(
        )
        """

    def testApiCrossStageViolationDTOV2(self):
        """Test ApiCrossStageViolationDTOV2"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
