# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.malware_defense_response_list import MalwareDefenseResponseList

class TestMalwareDefenseResponseList(unittest.TestCase):
    """MalwareDefenseResponseList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MalwareDefenseResponseList:
        """Test MalwareDefenseResponseList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MalwareDefenseResponseList`
        """
        model = MalwareDefenseResponseList()
        if include_optional:
            return MalwareDefenseResponseList(
                component_list = [
                    sonatype_iq_api_client.models.malware_defense_data.MalwareDefenseData(
                        hash = '', 
                        is_malicious = True, 
                        malware_categories = [
                            sonatype_iq_api_client.models.malware_category.MalwareCategory(
                                attack_vector = '', 
                                threat_types = [
                                    ''
                                    ], )
                            ], 
                        match_state = '', 
                        package_url = '', )
                    ]
            )
        else:
            return MalwareDefenseResponseList(
        )
        """

    def testMalwareDefenseResponseList(self):
        """Test MalwareDefenseResponseList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
