# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_evaluation_result_counter_dto import ApiEvaluationResultCounterDTO

class TestApiEvaluationResultCounterDTO(unittest.TestCase):
    """ApiEvaluationResultCounterDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiEvaluationResultCounterDTO:
        """Test ApiEvaluationResultCounterDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiEvaluationResultCounterDTO`
        """
        model = ApiEvaluationResultCounterDTO()
        if include_optional:
            return ApiEvaluationResultCounterDTO(
                critical = 56,
                moderate = 56,
                severe = 56
            )
        else:
            return ApiEvaluationResultCounterDTO(
        )
        """

    def testApiEvaluationResultCounterDTO(self):
        """Test ApiEvaluationResultCounterDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
