# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.api.sbom_api import SBOMApi


class TestSBOMApi(unittest.TestCase):
    """SBOMApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SBOMApi()

    def tearDown(self) -> None:
        pass

    def test_delete_sbom_version(self) -> None:
        """Test case for delete_sbom_version

        Delete sbom version
        """
        pass

    def test_delete_vulnerability_analysis(self) -> None:
        """Test case for delete_vulnerability_analysis

        Deletes a Vulnerability analysis for a given component.
        """
        pass

    def test_get_active_sbom_version_list_by_application(self) -> None:
        """Test case for get_active_sbom_version_list_by_application

        Gets a list of active sbom versions by application id
        """
        pass

    def test_get_import_status(self) -> None:
        """Test case for get_import_status

        Get sbom import status
        """
        pass

    def test_get_sbom_components(self) -> None:
        """Test case for get_sbom_components

        Gets the components found in a specific sbom version
        """
        pass

    def test_get_sbom_metadata_summary_for_application(self) -> None:
        """Test case for get_sbom_metadata_summary_for_application

        Gets a paginated list of SBOMs for an application
        """
        pass

    def test_get_sbom_version(self) -> None:
        """Test case for get_sbom_version

        Gets a sbom version
        """
        pass

    def test_get_vulnerability_details(self) -> None:
        """Test case for get_vulnerability_details

        """
        pass

    def test_import_sbom(self) -> None:
        """Test case for import_sbom

        Import a new sbom version
        """
        pass

    def test_save_vulnerability_analysis(self) -> None:
        """Test case for save_vulnerability_analysis

        Updates a vulnerability analysis annotation for a specific SBOM vulnerability
        """
        pass


if __name__ == '__main__':
    unittest.main()
