# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.system_config_property import SystemConfigProperty

class TestSystemConfigProperty(unittest.TestCase):
    """SystemConfigProperty unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSystemConfigProperty(self):
        """Test SystemConfigProperty"""
        # inst = SystemConfigProperty()

if __name__ == '__main__':
    unittest.main()
