# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_security_data_dto import ApiSecurityDataDTO

class TestApiSecurityDataDTO(unittest.TestCase):
    """ApiSecurityDataDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiSecurityDataDTO:
        """Test ApiSecurityDataDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiSecurityDataDTO`
        """
        model = ApiSecurityDataDTO()
        if include_optional:
            return ApiSecurityDataDTO(
                security_issues = [
                    sonatype_iq_api_client.models.api_security_issue_dto.ApiSecurityIssueDTO(
                        analysis = sonatype_iq_api_client.models.api_security_issue_analysis_dto.ApiSecurityIssueAnalysisDTO(
                            detail = '', 
                            justification = '', 
                            response = '', 
                            state = '', ), 
                        cvss_vector = '', 
                        cvss_vector_source = '', 
                        cwe = '', 
                        reference = '', 
                        severity = 1.337, 
                        source = '', 
                        status = '', 
                        threat_category = '', 
                        url = '', )
                    ]
            )
        else:
            return ApiSecurityDataDTO(
        )
        """

    def testApiSecurityDataDTO(self):
        """Test ApiSecurityDataDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
