# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.api.config_zscaler_api import ConfigZscalerApi


class TestConfigZscalerApi(unittest.TestCase):
    """ConfigZscalerApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ConfigZscalerApi()

    def tearDown(self) -> None:
        pass

    def test_delete_all_categories(self) -> None:
        """Test case for delete_all_categories

        """
        pass

    def test_delete_category(self) -> None:
        """Test case for delete_category

        """
        pass

    def test_delete_configuration6(self) -> None:
        """Test case for delete_configuration6

        """
        pass

    def test_get_configuration6(self) -> None:
        """Test case for get_configuration6

        """
        pass

    def test_get_quota(self) -> None:
        """Test case for get_quota

        """
        pass

    def test_set_configuration6(self) -> None:
        """Test case for set_configuration6

        """
        pass

    def test_test_configuration1(self) -> None:
        """Test case for test_configuration1

        """
        pass

    def test_trigger_update(self) -> None:
        """Test case for trigger_update

        """
        pass

    def test_trigger_update_all(self) -> None:
        """Test case for trigger_update_all

        """
        pass


if __name__ == '__main__':
    unittest.main()
