# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_application_categories_dto import ApiApplicationCategoriesDTO

class TestApiApplicationCategoriesDTO(unittest.TestCase):
    """ApiApplicationCategoriesDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiApplicationCategoriesDTO:
        """Test ApiApplicationCategoriesDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiApplicationCategoriesDTO`
        """
        model = ApiApplicationCategoriesDTO()
        if include_optional:
            return ApiApplicationCategoriesDTO(
                categories = [
                    sonatype_iq_api_client.models.api_application_category_dto.ApiApplicationCategoryDTO(
                        color = '', 
                        description = '', 
                        id = '', 
                        name = '', 
                        organization_id = '', )
                    ],
                contact_user_name = '',
                id = '',
                name = '',
                organization_id = '',
                public_id = ''
            )
        else:
            return ApiApplicationCategoriesDTO(
        )
        """

    def testApiApplicationCategoriesDTO(self):
        """Test ApiApplicationCategoriesDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
