# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_stale_evaluations_dto import ApiStaleEvaluationsDTO

class TestApiStaleEvaluationsDTO(unittest.TestCase):
    """ApiStaleEvaluationsDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiStaleEvaluationsDTO:
        """Test ApiStaleEvaluationsDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiStaleEvaluationsDTO`
        """
        model = ApiStaleEvaluationsDTO()
        if include_optional:
            return ApiStaleEvaluationsDTO(
                applications = [
                    sonatype_iq_api_client.models.api_stale_application_evaluation_dto.ApiStaleApplicationEvaluationDTO(
                        application = sonatype_iq_api_client.models.api_application_base_dto.ApiApplicationBaseDTO(
                            contact_user_name = '', 
                            id = '', 
                            name = '', 
                            organization_id = '', 
                            public_id = '', ), 
                        stages = [
                            sonatype_iq_api_client.models.api_stale_evaluation_stage_dto.ApiStaleEvaluationStageDTO(
                                last_evaluation_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                stage_id = '', )
                            ], )
                    ],
                repositories = [
                    sonatype_iq_api_client.models.api_stale_repository_evaluation_dto.ApiStaleRepositoryEvaluationDTO(
                        repository = sonatype_iq_api_client.models.api_repository_dto.ApiRepositoryDTO(
                            audit_enabled = True, 
                            format = '', 
                            namespace_confusion_protection_enabled = True, 
                            policy_compliant_component_selection_enabled = True, 
                            public_id = '', 
                            quarantine_enabled = True, 
                            repository_id = '', 
                            type = '', ), 
                        stages = [
                            sonatype_iq_api_client.models.api_stale_evaluation_stage_dto.ApiStaleEvaluationStageDTO(
                                last_evaluation_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                stage_id = '', )
                            ], )
                    ]
            )
        else:
            return ApiStaleEvaluationsDTO(
        )
        """

    def testApiStaleEvaluationsDTO(self):
        """Test ApiStaleEvaluationsDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
