# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.policy_container_waiver_data_result import PolicyContainerWaiverDataResult

class TestPolicyContainerWaiverDataResult(unittest.TestCase):
    """PolicyContainerWaiverDataResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PolicyContainerWaiverDataResult:
        """Test PolicyContainerWaiverDataResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PolicyContainerWaiverDataResult`
        """
        model = PolicyContainerWaiverDataResult()
        if include_optional:
            return PolicyContainerWaiverDataResult(
                page = 56,
                page_count = 56,
                page_size = 56,
                results = [
                    sonatype_iq_api_client.models.policy_container_waiver_data.PolicyContainerWaiverData(
                        application_scope = '', 
                        create_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expiry_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        max_threat_level = 56, 
                        owner_id = '', 
                        policy_waiver_id = '', 
                        unique_component_count = 56, 
                        unique_policy_count = 56, )
                    ],
                total = 56
            )
        else:
            return PolicyContainerWaiverDataResult(
        )
        """

    def testPolicyContainerWaiverDataResult(self):
        """Test PolicyContainerWaiverDataResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
