# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictStr
from typing import Optional
from typing_extensions import Annotated

from sonatype_iq_api_client.api_client import ApiClient, RequestSerialized
from sonatype_iq_api_client.api_response import ApiResponse
from sonatype_iq_api_client.rest import RESTResponseType


class SPDXApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_by_scan_id(
        self,
        application_id: Annotated[StrictStr, Field(description="Enter the applicationId for the application you want to generate the SBOM(s).")],
        scan_id: Annotated[StrictStr, Field(description="Enter the scanId of the application scan.")],
        format: Annotated[Optional[StrictStr], Field(description="Enter the format for the SBOM(s) to be generated.")] = None,
        generate_cyclone_dx: Annotated[Optional[StrictBool], Field(description="Set to `true` to generate an equivalent CycloneDx SBOM. Both SBOMs will be combined as a tar.gz archive.")] = None,
        spdx_version: Annotated[Optional[StrictStr], Field(description="Enter the desired SPDX version, possible values are 2.2|2.3")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> str:
        """get_by_scan_id

        Use this method to generate SBOM(s) based on a specific application scan.  Permissions required: View IQ Elemets

        :param application_id: Enter the applicationId for the application you want to generate the SBOM(s). (required)
        :type application_id: str
        :param scan_id: Enter the scanId of the application scan. (required)
        :type scan_id: str
        :param format: Enter the format for the SBOM(s) to be generated.
        :type format: str
        :param generate_cyclone_dx: Set to `true` to generate an equivalent CycloneDx SBOM. Both SBOMs will be combined as a tar.gz archive.
        :type generate_cyclone_dx: bool
        :param spdx_version: Enter the desired SPDX version, possible values are 2.2|2.3
        :type spdx_version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_by_scan_id_serialize(
            application_id=application_id,
            scan_id=scan_id,
            format=format,
            generate_cyclone_dx=generate_cyclone_dx,
            spdx_version=spdx_version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "str",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_by_scan_id_with_http_info(
        self,
        application_id: Annotated[StrictStr, Field(description="Enter the applicationId for the application you want to generate the SBOM(s).")],
        scan_id: Annotated[StrictStr, Field(description="Enter the scanId of the application scan.")],
        format: Annotated[Optional[StrictStr], Field(description="Enter the format for the SBOM(s) to be generated.")] = None,
        generate_cyclone_dx: Annotated[Optional[StrictBool], Field(description="Set to `true` to generate an equivalent CycloneDx SBOM. Both SBOMs will be combined as a tar.gz archive.")] = None,
        spdx_version: Annotated[Optional[StrictStr], Field(description="Enter the desired SPDX version, possible values are 2.2|2.3")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[str]:
        """get_by_scan_id

        Use this method to generate SBOM(s) based on a specific application scan.  Permissions required: View IQ Elemets

        :param application_id: Enter the applicationId for the application you want to generate the SBOM(s). (required)
        :type application_id: str
        :param scan_id: Enter the scanId of the application scan. (required)
        :type scan_id: str
        :param format: Enter the format for the SBOM(s) to be generated.
        :type format: str
        :param generate_cyclone_dx: Set to `true` to generate an equivalent CycloneDx SBOM. Both SBOMs will be combined as a tar.gz archive.
        :type generate_cyclone_dx: bool
        :param spdx_version: Enter the desired SPDX version, possible values are 2.2|2.3
        :type spdx_version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_by_scan_id_serialize(
            application_id=application_id,
            scan_id=scan_id,
            format=format,
            generate_cyclone_dx=generate_cyclone_dx,
            spdx_version=spdx_version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "str",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_by_scan_id_without_preload_content(
        self,
        application_id: Annotated[StrictStr, Field(description="Enter the applicationId for the application you want to generate the SBOM(s).")],
        scan_id: Annotated[StrictStr, Field(description="Enter the scanId of the application scan.")],
        format: Annotated[Optional[StrictStr], Field(description="Enter the format for the SBOM(s) to be generated.")] = None,
        generate_cyclone_dx: Annotated[Optional[StrictBool], Field(description="Set to `true` to generate an equivalent CycloneDx SBOM. Both SBOMs will be combined as a tar.gz archive.")] = None,
        spdx_version: Annotated[Optional[StrictStr], Field(description="Enter the desired SPDX version, possible values are 2.2|2.3")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_by_scan_id

        Use this method to generate SBOM(s) based on a specific application scan.  Permissions required: View IQ Elemets

        :param application_id: Enter the applicationId for the application you want to generate the SBOM(s). (required)
        :type application_id: str
        :param scan_id: Enter the scanId of the application scan. (required)
        :type scan_id: str
        :param format: Enter the format for the SBOM(s) to be generated.
        :type format: str
        :param generate_cyclone_dx: Set to `true` to generate an equivalent CycloneDx SBOM. Both SBOMs will be combined as a tar.gz archive.
        :type generate_cyclone_dx: bool
        :param spdx_version: Enter the desired SPDX version, possible values are 2.2|2.3
        :type spdx_version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_by_scan_id_serialize(
            application_id=application_id,
            scan_id=scan_id,
            format=format,
            generate_cyclone_dx=generate_cyclone_dx,
            spdx_version=spdx_version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "str",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_by_scan_id_serialize(
        self,
        application_id,
        scan_id,
        format,
        generate_cyclone_dx,
        spdx_version,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if application_id is not None:
            _path_params['applicationId'] = application_id
        if scan_id is not None:
            _path_params['scanId'] = scan_id
        # process the query parameters
        if format is not None:
            
            _query_params.append(('format', format))
            
        if generate_cyclone_dx is not None:
            
            _query_params.append(('generateCycloneDx', generate_cyclone_dx))
            
        if spdx_version is not None:
            
            _query_params.append(('spdxVersion', spdx_version))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json', 
                    'application/octet-stream', 
                    'application/xml'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v2/spdx/{applicationId}/reports/{scanId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_latest_for_stage(
        self,
        application_id: Annotated[StrictStr, Field(description="Enter the applicationId for the application you want to generate the SBOM(s).")],
        stage_id: Annotated[StrictStr, Field(description="Specify the stageId for the application evaluation. Allowed values are `develop`, `build`, `stage-release`, `release` and `operate`.")],
        format: Annotated[Optional[StrictStr], Field(description="Enter the format for the SBOM(s) to be generated.")] = None,
        generate_cyclone_dx: Annotated[Optional[StrictBool], Field(description="Set to `true` to generate an equivalent CycloneDx SBOM. Both SBOMs will be combined as a tar.gz archive.")] = None,
        spdx_version: Annotated[Optional[StrictStr], Field(description="Enter the desired SPDX version, possible values are 2.2|2.3")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> str:
        """get_latest_for_stage

        Use this method to generate SBOM(s) based on the latest application evaluation report at the specified stage.  Permissions required: View IQ Elements

        :param application_id: Enter the applicationId for the application you want to generate the SBOM(s). (required)
        :type application_id: str
        :param stage_id: Specify the stageId for the application evaluation. Allowed values are `develop`, `build`, `stage-release`, `release` and `operate`. (required)
        :type stage_id: str
        :param format: Enter the format for the SBOM(s) to be generated.
        :type format: str
        :param generate_cyclone_dx: Set to `true` to generate an equivalent CycloneDx SBOM. Both SBOMs will be combined as a tar.gz archive.
        :type generate_cyclone_dx: bool
        :param spdx_version: Enter the desired SPDX version, possible values are 2.2|2.3
        :type spdx_version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_latest_for_stage_serialize(
            application_id=application_id,
            stage_id=stage_id,
            format=format,
            generate_cyclone_dx=generate_cyclone_dx,
            spdx_version=spdx_version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "str",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_latest_for_stage_with_http_info(
        self,
        application_id: Annotated[StrictStr, Field(description="Enter the applicationId for the application you want to generate the SBOM(s).")],
        stage_id: Annotated[StrictStr, Field(description="Specify the stageId for the application evaluation. Allowed values are `develop`, `build`, `stage-release`, `release` and `operate`.")],
        format: Annotated[Optional[StrictStr], Field(description="Enter the format for the SBOM(s) to be generated.")] = None,
        generate_cyclone_dx: Annotated[Optional[StrictBool], Field(description="Set to `true` to generate an equivalent CycloneDx SBOM. Both SBOMs will be combined as a tar.gz archive.")] = None,
        spdx_version: Annotated[Optional[StrictStr], Field(description="Enter the desired SPDX version, possible values are 2.2|2.3")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[str]:
        """get_latest_for_stage

        Use this method to generate SBOM(s) based on the latest application evaluation report at the specified stage.  Permissions required: View IQ Elements

        :param application_id: Enter the applicationId for the application you want to generate the SBOM(s). (required)
        :type application_id: str
        :param stage_id: Specify the stageId for the application evaluation. Allowed values are `develop`, `build`, `stage-release`, `release` and `operate`. (required)
        :type stage_id: str
        :param format: Enter the format for the SBOM(s) to be generated.
        :type format: str
        :param generate_cyclone_dx: Set to `true` to generate an equivalent CycloneDx SBOM. Both SBOMs will be combined as a tar.gz archive.
        :type generate_cyclone_dx: bool
        :param spdx_version: Enter the desired SPDX version, possible values are 2.2|2.3
        :type spdx_version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_latest_for_stage_serialize(
            application_id=application_id,
            stage_id=stage_id,
            format=format,
            generate_cyclone_dx=generate_cyclone_dx,
            spdx_version=spdx_version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "str",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_latest_for_stage_without_preload_content(
        self,
        application_id: Annotated[StrictStr, Field(description="Enter the applicationId for the application you want to generate the SBOM(s).")],
        stage_id: Annotated[StrictStr, Field(description="Specify the stageId for the application evaluation. Allowed values are `develop`, `build`, `stage-release`, `release` and `operate`.")],
        format: Annotated[Optional[StrictStr], Field(description="Enter the format for the SBOM(s) to be generated.")] = None,
        generate_cyclone_dx: Annotated[Optional[StrictBool], Field(description="Set to `true` to generate an equivalent CycloneDx SBOM. Both SBOMs will be combined as a tar.gz archive.")] = None,
        spdx_version: Annotated[Optional[StrictStr], Field(description="Enter the desired SPDX version, possible values are 2.2|2.3")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_latest_for_stage

        Use this method to generate SBOM(s) based on the latest application evaluation report at the specified stage.  Permissions required: View IQ Elements

        :param application_id: Enter the applicationId for the application you want to generate the SBOM(s). (required)
        :type application_id: str
        :param stage_id: Specify the stageId for the application evaluation. Allowed values are `develop`, `build`, `stage-release`, `release` and `operate`. (required)
        :type stage_id: str
        :param format: Enter the format for the SBOM(s) to be generated.
        :type format: str
        :param generate_cyclone_dx: Set to `true` to generate an equivalent CycloneDx SBOM. Both SBOMs will be combined as a tar.gz archive.
        :type generate_cyclone_dx: bool
        :param spdx_version: Enter the desired SPDX version, possible values are 2.2|2.3
        :type spdx_version: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_latest_for_stage_serialize(
            application_id=application_id,
            stage_id=stage_id,
            format=format,
            generate_cyclone_dx=generate_cyclone_dx,
            spdx_version=spdx_version,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "str",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_latest_for_stage_serialize(
        self,
        application_id,
        stage_id,
        format,
        generate_cyclone_dx,
        spdx_version,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if application_id is not None:
            _path_params['applicationId'] = application_id
        if stage_id is not None:
            _path_params['stageId'] = stage_id
        # process the query parameters
        if format is not None:
            
            _query_params.append(('format', format))
            
        if generate_cyclone_dx is not None:
            
            _query_params.append(('generateCycloneDx', generate_cyclone_dx))
            
        if spdx_version is not None:
            
            _query_params.append(('spdxVersion', spdx_version))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json', 
                    'application/octet-stream', 
                    'application/xml'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v2/spdx/{applicationId}/stages/{stageId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )


