# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_repository_component_evaluation_result_list import ApiRepositoryComponentEvaluationResultList

class TestApiRepositoryComponentEvaluationResultList(unittest.TestCase):
    """ApiRepositoryComponentEvaluationResultList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiRepositoryComponentEvaluationResultList:
        """Test ApiRepositoryComponentEvaluationResultList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiRepositoryComponentEvaluationResultList`
        """
        model = ApiRepositoryComponentEvaluationResultList()
        if include_optional:
            return ApiRepositoryComponentEvaluationResultList(
                repository_id = '',
                repository_manager_id = '',
                repository_public_id = '',
                repository_type = '',
                results = [
                    sonatype_iq_api_client.models.api_repository_component_evaluation_result.ApiRepositoryComponentEvaluationResult(
                        catalog_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        component = sonatype_iq_api_client.models.api_repository_component_evaluation_request.ApiRepositoryComponentEvaluationRequest(
                            hash = '', 
                            package_url = '', 
                            pathname = '', ), 
                        policy_violations = [
                            sonatype_iq_api_client.models.api_policy_violation_dtov2.ApiPolicyViolationDTOV2(
                                constraint_violations = [
                                    sonatype_iq_api_client.models.api_constraint_violation_dto.ApiConstraintViolationDTO(
                                        constraint_id = '', 
                                        constraint_name = '', 
                                        reasons = [
                                            sonatype_iq_api_client.models.api_constraint_violation_reason_dto.ApiConstraintViolationReasonDTO(
                                                reason = '', 
                                                reference = sonatype_iq_api_client.models.trigger_reference.TriggerReference(
                                                    type = 'SECURITY_VULNERABILITY_REFID', 
                                                    value = '', ), )
                                            ], )
                                    ], 
                                fix_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                legacy_violation_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                open_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                policy_id = '', 
                                policy_name = '', 
                                policy_violation_id = '', 
                                threat_level = 56, 
                                waive_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        quarantine_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        quarantined = True, )
                    ]
            )
        else:
            return ApiRepositoryComponentEvaluationResultList(
        )
        """

    def testApiRepositoryComponentEvaluationResultList(self):
        """Test ApiRepositoryComponentEvaluationResultList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
