# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_suggested_version_change_option_dto import ApiSuggestedVersionChangeOptionDTO

class TestApiSuggestedVersionChangeOptionDTO(unittest.TestCase):
    """ApiSuggestedVersionChangeOptionDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiSuggestedVersionChangeOptionDTO:
        """Test ApiSuggestedVersionChangeOptionDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiSuggestedVersionChangeOptionDTO`
        """
        model = ApiSuggestedVersionChangeOptionDTO()
        if include_optional:
            return ApiSuggestedVersionChangeOptionDTO(
                data = sonatype_iq_api_client.models.api_component_change_action_dto.ApiComponentChangeActionDTO(
                    component = sonatype_iq_api_client.models.api_component_dtov2.ApiComponentDTOV2(
                        component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                            coordinates = {
                                'key' : ''
                                }, 
                            format = '', ), 
                        display_name = '', 
                        hash = '', 
                        package_url = '', 
                        proprietary = True, 
                        sha256 = '', 
                        third_party = True, ), ),
                direct_dependency = True,
                direct_dependency_data = [
                    sonatype_iq_api_client.models.api_component_change_action_dto.ApiComponentChangeActionDTO(
                        component = sonatype_iq_api_client.models.api_component_dtov2.ApiComponentDTOV2(
                            component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                                coordinates = {
                                    'key' : ''
                                    }, 
                                format = '', ), 
                            display_name = '', 
                            hash = '', 
                            package_url = '', 
                            proprietary = True, 
                            sha256 = '', 
                            third_party = True, ), )
                    ],
                is_golden = True,
                type = 'next-no-violations'
            )
        else:
            return ApiSuggestedVersionChangeOptionDTO(
        )
        """

    def testApiSuggestedVersionChangeOptionDTO(self):
        """Test ApiSuggestedVersionChangeOptionDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
