# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.api.source_control_api import SourceControlApi


class TestSourceControlApi(unittest.TestCase):
    """SourceControlApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SourceControlApi()

    def tearDown(self) -> None:
        pass

    def test_add_source_control(self) -> None:
        """Test case for add_source_control

        """
        pass

    def test_add_user_mappings(self) -> None:
        """Test case for add_user_mappings

        """
        pass

    def test_automatic_role_assignment(self) -> None:
        """Test case for automatic_role_assignment

        """
        pass

    def test_delete_source_control(self) -> None:
        """Test case for delete_source_control

        """
        pass

    def test_delete_user_mappings(self) -> None:
        """Test case for delete_user_mappings

        """
        pass

    def test_get_source_control1(self) -> None:
        """Test case for get_source_control1

        """
        pass

    def test_get_user_mappings_by_owner(self) -> None:
        """Test case for get_user_mappings_by_owner

        """
        pass

    def test_update_source_control(self) -> None:
        """Test case for update_source_control

        """
        pass


if __name__ == '__main__':
    unittest.main()
