# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.api.user_tokens_api import UserTokensApi


class TestUserTokensApi(unittest.TestCase):
    """UserTokensApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UserTokensApi()

    def tearDown(self) -> None:
        pass

    def test_create_user_token(self) -> None:
        """Test case for create_user_token

        """
        pass

    def test_delete_current_user_token(self) -> None:
        """Test case for delete_current_user_token

        """
        pass

    def test_delete_user_token_by_user_code(self) -> None:
        """Test case for delete_user_token_by_user_code

        """
        pass

    def test_get_user_token_by_username_and_realm_id(self) -> None:
        """Test case for get_user_token_by_username_and_realm_id

        """
        pass

    def test_get_user_token_exists_for_current_user(self) -> None:
        """Test case for get_user_token_exists_for_current_user

        """
        pass

    def test_get_user_tokens_by_created_between_and_realm_id(self) -> None:
        """Test case for get_user_tokens_by_created_between_and_realm_id

        """
        pass

    def test_purge_user_tokens(self) -> None:
        """Test case for purge_user_tokens

        """
        pass


if __name__ == '__main__':
    unittest.main()
