# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_hash_component_identifier_dto import ApiHashComponentIdentifierDTO

class TestApiHashComponentIdentifierDTO(unittest.TestCase):
    """ApiHashComponentIdentifierDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiHashComponentIdentifierDTO:
        """Test ApiHashComponentIdentifierDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiHashComponentIdentifierDTO`
        """
        model = ApiHashComponentIdentifierDTO()
        if include_optional:
            return ApiHashComponentIdentifierDTO(
                claimer_id = '',
                claimer_name = '',
                comment = '',
                component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                    coordinates = {
                        'key' : ''
                        }, 
                    format = '', ),
                create_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                hash = '',
                package_url = ''
            )
        else:
            return ApiHashComponentIdentifierDTO(
        )
        """

    def testApiHashComponentIdentifierDTO(self):
        """Test ApiHashComponentIdentifierDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
