# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_security_vulnerability_override_response_dtov2 import ApiSecurityVulnerabilityOverrideResponseDTOV2

class TestApiSecurityVulnerabilityOverrideResponseDTOV2(unittest.TestCase):
    """ApiSecurityVulnerabilityOverrideResponseDTOV2 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiSecurityVulnerabilityOverrideResponseDTOV2:
        """Test ApiSecurityVulnerabilityOverrideResponseDTOV2
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiSecurityVulnerabilityOverrideResponseDTOV2`
        """
        model = ApiSecurityVulnerabilityOverrideResponseDTOV2()
        if include_optional:
            return ApiSecurityVulnerabilityOverrideResponseDTOV2(
                security_overrides = [
                    sonatype_iq_api_client.models.api_security_vulnerability_override_dtov2.ApiSecurityVulnerabilityOverrideDTOV2(
                        comment = '', 
                        currently_affected_components = [
                            sonatype_iq_api_client.models.api_component_dtov2.ApiComponentDTOV2(
                                component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                                    coordinates = {
                                        'key' : ''
                                        }, 
                                    format = '', ), 
                                display_name = '', 
                                hash = '', 
                                package_url = '', 
                                proprietary = True, 
                                sha256 = '', 
                                third_party = True, )
                            ], 
                        hash = '', 
                        owner = sonatype_iq_api_client.models.api_owner_dto.ApiOwnerDTO(
                            owner_id = '', 
                            owner_name = '', 
                            owner_public_id = '', 
                            owner_type = '', ), 
                        reference_id = '', 
                        security_override_id = '', 
                        status = '', )
                    ]
            )
        else:
            return ApiSecurityVulnerabilityOverrideResponseDTOV2(
        )
        """

    def testApiSecurityVulnerabilityOverrideResponseDTOV2(self):
        """Test ApiSecurityVulnerabilityOverrideResponseDTOV2"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
