# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.api.firewall_api import FirewallApi


class TestFirewallApi(unittest.TestCase):
    """FirewallApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FirewallApi()

    def tearDown(self) -> None:
        pass

    def test_add_proprietary_component_names(self) -> None:
        """Test case for add_proprietary_component_names

        """
        pass

    def test_add_repository_manager(self) -> None:
        """Test case for add_repository_manager

        """
        pass

    def test_add_waiver(self) -> None:
        """Test case for add_waiver

        """
        pass

    def test_configure_repositories(self) -> None:
        """Test case for configure_repositories

        """
        pass

    def test_delete_container_image_policy_waiver(self) -> None:
        """Test case for delete_container_image_policy_waiver

        """
        pass

    def test_delete_repository_manager(self) -> None:
        """Test case for delete_repository_manager

        """
        pass

    def test_evaluate_components1(self) -> None:
        """Test case for evaluate_components1

        """
        pass

    def test_evaluate_malware(self) -> None:
        """Test case for evaluate_malware

        """
        pass

    def test_get_configured_repositories(self) -> None:
        """Test case for get_configured_repositories

        """
        pass

    def test_get_container_images_in_quarantine(self) -> None:
        """Test case for get_container_images_in_quarantine

        """
        pass

    def test_get_firewall_auto_unquarantine_config(self) -> None:
        """Test case for get_firewall_auto_unquarantine_config

        """
        pass

    def test_get_firewall_metrics(self) -> None:
        """Test case for get_firewall_metrics

        """
        pass

    def test_get_firewall_unquarantine_summary(self) -> None:
        """Test case for get_firewall_unquarantine_summary

        """
        pass

    def test_get_malware_defense_metrics(self) -> None:
        """Test case for get_malware_defense_metrics

        """
        pass

    def test_get_quarantine_list(self) -> None:
        """Test case for get_quarantine_list

        """
        pass

    def test_get_quarantine_summary(self) -> None:
        """Test case for get_quarantine_summary

        """
        pass

    def test_get_quarantined_component_view_anonymous_access(self) -> None:
        """Test case for get_quarantined_component_view_anonymous_access

        """
        pass

    def test_get_repository_container(self) -> None:
        """Test case for get_repository_container

        """
        pass

    def test_get_repository_manager(self) -> None:
        """Test case for get_repository_manager

        """
        pass

    def test_get_repository_managers(self) -> None:
        """Test case for get_repository_managers

        """
        pass

    def test_get_unquarantine_list(self) -> None:
        """Test case for get_unquarantine_list

        """
        pass

    def test_get_waivers(self) -> None:
        """Test case for get_waivers

        """
        pass

    def test_remove_proprietary_component_names(self) -> None:
        """Test case for remove_proprietary_component_names

        """
        pass

    def test_set_firewall_auto_unquarantine_config(self) -> None:
        """Test case for set_firewall_auto_unquarantine_config

        """
        pass

    def test_set_quarantined_component_view_anonymous_access(self) -> None:
        """Test case for set_quarantined_component_view_anonymous_access

        """
        pass


if __name__ == '__main__':
    unittest.main()
