# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.api.application_categories_api import ApplicationCategoriesApi


class TestApplicationCategoriesApi(unittest.TestCase):
    """ApplicationCategoriesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApplicationCategoriesApi()

    def tearDown(self) -> None:
        pass

    def test_add_tag(self) -> None:
        """Test case for add_tag

        """
        pass

    def test_delete_tag(self) -> None:
        """Test case for delete_tag

        """
        pass

    def test_get_applicable_tags(self) -> None:
        """Test case for get_applicable_tags

        """
        pass

    def test_get_applicable_tags_by_application_public_id(self) -> None:
        """Test case for get_applicable_tags_by_application_public_id

        """
        pass

    def test_get_application_applicable_tags(self) -> None:
        """Test case for get_application_applicable_tags

        """
        pass

    def test_get_applied_policy_tags(self) -> None:
        """Test case for get_applied_policy_tags

        """
        pass

    def test_get_applied_tags(self) -> None:
        """Test case for get_applied_tags

        """
        pass

    def test_get_tags(self) -> None:
        """Test case for get_tags

        """
        pass

    def test_get_tags_used_by_applications(self) -> None:
        """Test case for get_tags_used_by_applications

        """
        pass

    def test_update_tag(self) -> None:
        """Test case for update_tag

        """
        pass


if __name__ == '__main__':
    unittest.main()
