# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_dependency_tree_response_dto import ApiDependencyTreeResponseDTO

class TestApiDependencyTreeResponseDTO(unittest.TestCase):
    """ApiDependencyTreeResponseDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiDependencyTreeResponseDTO:
        """Test ApiDependencyTreeResponseDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiDependencyTreeResponseDTO`
        """
        model = ApiDependencyTreeResponseDTO()
        if include_optional:
            return ApiDependencyTreeResponseDTO(
                dependency_tree = sonatype_iq_api_client.models.api_dependency_tree_node_dto.ApiDependencyTreeNodeDTO(
                    children = [
                        sonatype_iq_api_client.models.api_dependency_tree_node_dto.ApiDependencyTreeNodeDTO(
                            component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                                coordinates = {
                                    'key' : ''
                                    }, 
                                format = '', ), 
                            direct = True, 
                            package_url = '', )
                        ], 
                    component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                        format = '', ), 
                    direct = True, 
                    package_url = '', )
            )
        else:
            return ApiDependencyTreeResponseDTO(
        )
        """

    def testApiDependencyTreeResponseDTO(self):
        """Test ApiDependencyTreeResponseDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
